@@ -96,8 +96,8 @@ List* mtf_find(void *data, int multiseq, int motif_size, int nmotifs,
   Hashtable *hash;
 
   cons_str[motif_size] = '\0';
-  alph_size = multiseq ? strlen(pmsa->pooled_msa->alphabet) : 
-    strlen(seqset->set->alphabet);
+  alph_size = multiseq ? (int)strlen(pmsa->pooled_msa->alphabet) : 
+    (int)strlen(seqset->set->alphabet);
   alpha = smalloc(alph_size * sizeof(double));
   for (i = 0; i < alph_size; i++) alpha[i] = 1;      
   for (i = 0; i <= motif_size; i++) freqs[i] = vec_new(alph_size);
@@ -198,7 +198,7 @@ List* mtf_find(void *data, int multiseq, int motif_size, int nmotifs,
                           lower_bounds, upper_bounds, NULL,
                           NUMERICAL_DERIVS ? NULL : 
                           mtf_compute_conditional_grad, 
-                          OPT_LOW_PREC, NULL);
+                          OPT_LOW_PREC, NULL, NULL);
 
         m->score *= -1;
 
@@ -297,7 +297,7 @@ void mn_estim_mods(void **models, int nmodels, void *data,
    the inv_alphabet for the specified sequence and position */
 int mn_get_obs_idx(void *data, int sample, int position) {
   MSA *set = ((SeqSet*)data)->set;
-  if (sample < 0 || position < 0) return strlen(set->alphabet);
+  if (sample < 0 || position < 0) return (int)strlen(set->alphabet);
                                 /* this hack lets the EM code figure
                                    out the size of state space */
   return set->inv_alphabet[(int)set->seqs[sample][position]];
@@ -314,7 +314,7 @@ void phy_compute_emissions(double **emissions, void **models, int nmodels,
                                    ignored by setting to NULL */
       MSA *smsa = lst_get_ptr(pmsa->source_msas, sample);
       tl_compute_log_likelihood((TreeModel*)models[k], smsa, 
-                                emissions[k], -1, NULL);
+                                emissions[k], NULL, -1, NULL);
       for (i = 0; i < smsa->length; i++) emissions[k][i] *= conv_factor;
                                 /* convert to natural log scale */
     }
@@ -333,7 +333,7 @@ void phy_estim_mods(void **models, int nmodels, void *data,
     params = tm_params_new_init_from_model(tm);
     for (obsidx = 0; obsidx < nobs; obsidx++) 
       pmsa->pooled_msa->ss->cat_counts[k][obsidx] = E[k][obsidx];
-    tm_fit(tm, pmsa->pooled_msa, params, k, OPT_HIGH_PREC, NULL, 1);
+    tm_fit(tm, pmsa->pooled_msa, params, k, OPT_HIGH_PREC, NULL, 1, NULL);
 /*     fprintf(stderr, "%d: %f, %f\n", k, tm->scale, tr_total_len(tm->tree)); */
     vec_free(params); 
   }
@@ -630,7 +630,7 @@ void mtf_compute_inner_derivs_phy(double **derivs, Motif *m,
   for (mod = 1; mod <= m->motif_size; mod++) {
     int nparams_this_model = tm_get_nparams(m->ph_mods[mod]);
     tm_unpack_params(m->ph_mods[mod], params, base_param_idx);
-    tl_compute_log_likelihood(m->ph_mods[mod], dummy_msa, col_ll, -1, NULL);
+    tl_compute_log_likelihood(m->ph_mods[mod], dummy_msa, col_ll, NULL, -1, NULL);
     for (k = 0; k < nparams_this_model; k++) {
       double origparm;
       i = base_param_idx + k;   /* index of parameter of interest */
@@ -638,7 +638,7 @@ void mtf_compute_inner_derivs_phy(double **derivs, Motif *m,
       vec_set(params, i, origparm + DERIV_EPSILON);
       tm_unpack_params(m->ph_mods[mod], params, base_param_idx);
       tl_compute_log_likelihood(m->ph_mods[mod], dummy_msa, col_ll_tweak, 
-                                -1, NULL);
+                                NULL, -1, NULL);
 
       for (j = 0; j < dummy_msa->ss->ntuples; j++)
         derivs[i][j] = conv_factor * (col_ll_tweak[j] - col_ll[j]) / 
@@ -880,7 +880,7 @@ void mtf_draw_multinomial(Vector *v, double *alpha) {
 /* scan a set of DNA sequences for the most prevalent n-tuples of bases */
 void mtf_get_common_ntuples(SeqSet *s, List *tuples, int tuple_size, 
                             int number) {
-  int alph_size = strlen(s->set->alphabet);
+  int alph_size = (int)strlen(s->set->alphabet);
   int idx, cutoff, i, j, k;
   int ntuples = int_pow(alph_size, tuple_size), high = ntuples/alph_size;
   int *counts = smalloc(ntuples * sizeof(int));
@@ -940,10 +940,10 @@ void mtf_sample_ntuples(SeqSet *s, List *tuples, int tuple_size, int number) {
   tuple[tuple_size] = '\0';
   /* for simplicity, we'll assume they're all about the same length,
      and sample number/seqset->nseqs from each sequence */
-  n = ceil(1.0 * number/s->set->nseqs);
+  n = (int)ceil(1.0 * number/s->set->nseqs);
   for (i = 0; i < s->set->nseqs && lst_size(tuples) < number; i++) {
     for (j = 0; j < n && lst_size(tuples) < number; j++) {
-      int start = rint(1.0 * (s->lens[i] - tuple_size) * unif_rand());
+      int start = (int)rint(1.0 * (s->lens[i] - tuple_size) * unif_rand());
       strncpy(tuple, &s->set->seqs[i][start], tuple_size);
       lst_push_ptr(tuples, str_new_charstr(tuple));
     }
@@ -1006,8 +1006,8 @@ void mtf_winnow_starts(void *data, List *origseqs, int ntochoose,
   SeqSet *ss = !multiseq ? data : NULL;
   PooledMSA *pmsa = multiseq ? data : NULL;
   Vector **freqs = smalloc((motif_size + 1) * sizeof(void*));
-  int alph_size = multiseq ? strlen(pmsa->pooled_msa->alphabet) : 
-    strlen(ss->set->alphabet);
+  int alph_size = multiseq ? (int)strlen(pmsa->pooled_msa->alphabet) : 
+    (int)strlen(ss->set->alphabet);
   int *inv_alphabet = multiseq ? pmsa->pooled_msa->inv_alphabet :
     ss->set->inv_alphabet;
   int nsamples = multiseq ? lst_size(pmsa->source_msas) : ss->set->nseqs;
@@ -1244,7 +1244,7 @@ Motif* mtf_new(int motif_size, int multiseq, Vector **freqs,
     m->refseq = -1;
   }
 
-  m->alph_size = strlen(m->alphabet);
+  m->alph_size = (int)strlen(m->alphabet);
   m->postprob = smalloc(n * sizeof(double));
   m->bestposition = smalloc(n * sizeof(int));
   m->samplescore = smalloc(n * sizeof(double));
@@ -1885,7 +1885,7 @@ void mtf_add_features(Motif *m, GFF_Set *gff) {
 /*   *bestlogl = NEGINFTY; */
 
   /* estimate background model */
-/*   pmsa = ss_pooled_from_msas(msas, 1, motif_size, NULL); */
+/*   pmsa = ss_pooled_from_msas(msas, 1, motif_size, NULL, 0); */
 
 /*   msa_remove_N_from_alph(pmsa->pooled_msa); */
 /*   for (i = 0; i < lst_size(pmsa->source_msas); i++) */
